@@ -1,13 +1,13 @@
 # !/usr/bin/env python3  Line 1
 # -*- coding: utf-8 -*- Line 2
 # ----------------------------------------------------------------------------
-# FastAPI MSA SDK, shared SDK for multiple Micro Services Platform/Systems
+# FastAPI msaSDK, shared SDK for multiple Micro Services Platform/Systems
 #
 # Created By  : Stefan Welcker/U2D.ai
 # Created Date: 23.08.2022
 # ---------------------------------------------------------------------------
 
-version = '0.1.1'
+version = '0.1.2'
 __author__ = "Stefan Welcker"
 __copyright__ = "Copyright 2022, U2D.ai"
 __license__ = "MIT"
@@ -15,7 +15,7 @@ __version__ = version
 __maintainer__ = "Stefan Welcker"
 __email__ = "stefan@u2d,.ai"
 __status__ = "Beta"
-
+__url__ = "https://github.com/swelcker/U2D_MSA_SDK"
 
 from os.path import dirname, basename, isfile, join
 import glob
