@@ -2,7 +2,6 @@
 """
 Copyright (c) 2022 - U2D.ai / S.Welcker
 """
-__version__ = '0.1.1'
 
 from typing import Optional
 
@@ -15,11 +14,11 @@ from msaSDK.utils.scheduler import MSATimers, MSATimerEnum
 
 
 async def test_timer_min():
-    app.logger.info("MSA SDK Test Timer Async Every Minute")
+    app.logger.info("msaSDK Test Timer Async Every Minute")
 
 
 def test_timer_five_sec():
-    app.logger.info("MSA SDK Test Timer Sync 5 Second")
+    app.logger.info("msaSDK Test Timer Sync 5 Second")
 
 
 class TestArticle(SQLModel, table=True):
@@ -42,8 +41,8 @@ class TestCategory(SQLModel, table=True):
 
 get_msa_app_settings.cache_clear()
 settings = get_msa_app_settings()
-settings.title = "SPK.ai - MSA/SDK MVP"
-settings.version = "SPK.0.0.1"
+settings.title = "u2d.ai - MSA/SDK MVP"
+settings.version = "0.0.1"
 settings.debug = True
 
 my_timers: MSATimers = MSATimers()
@@ -52,7 +51,7 @@ my_timers.create_timer(MSATimerEnum.on_the_5_second, test_timer_five_sec)
 
 app = MSAApp(settings=settings, timers=my_timers, auto_mount_site=True,
              sql_models=[TestArticle, TestCategory],
-             contact={"name": "MSA SDK", "url": "http://u2d.ai", "email": "stefan@u2d.ai"},
+             contact={"name": "msaSDK", "url": "http://u2d.ai", "email": "stefan@u2d.ai"},
              license_info={"name": "MIT", "url": "https://opensource.org/licenses/MIT", })
 
 
@@ -61,13 +60,13 @@ app.logger.info("Initialized " + settings.title + " " + settings.version)
 
 @app.on_event("startup")
 async def startup():
-    app.logger.info("MSA SDK Own Startup MSAUIEvent")
+    app.logger.info("msaSDK Own Startup MSAUIEvent")
     #app.mount_site()
 
 
 @app.on_event("shutdown")
 async def shutdown():
-    app.logger.info("MSA SDK Own Shutdown MSAUIEvent")
+    app.logger.info("msaSDK Own Shutdown MSAUIEvent")
 
 
 if __name__ == '__main__':
