@@ -6,17 +6,20 @@ from .models import UsernameMixin, PasswordMixin, EmailMixin, BaseUser
 
 
 class BaseTokenData(BaseModel):
+    """Pydantic Model for TokenData"""
     id: int
     username: str
 
 
 class UserLoginOut(BaseUser):
+    """Pydantic Response/Output Model for User Login"""
     token_type: str = 'bearer'
     access_token: str = None
     password: SecretStr = None
 
 
 class UserRegIn(UsernameMixin, PasswordMixin, EmailMixin):
+    """User Registration Input Pydantic Model"""
     password2: str = Field(title=_('Confirm Password'), max_length=128)
 
     @validator('password2')
