@@ -60,11 +60,6 @@ from msaSDK.utils.profiler import MSAProfilerMiddleware
 from msaSDK.utils.scheduler import MSATimers, MSAScheduler
 from msaSDK.utils.sysinfo import get_sysinfo, MSASystemInfo
 
-__version__ = '0.1.1'
-""" str: Module Version"""
-
-if __name__ == '__main__':
-    pass
 
 security_context = CryptContext(schemes=["bcrypt"], deprecated="auto")
 """Security Context for Password Helper"""
@@ -89,7 +84,7 @@ class MSASchedulerStatus(SQLModel):
     """
     **MSASchedulerStatus** Pydantic Response Class
     """
-    name: Optional[str] = "MSA SDK Service"
+    name: Optional[str] = "msaSDK Service"
     """Service Name."""
     timers: Optional[List[MSATimerStatus]] = []
     """Optional MSATimerStatus List"""
@@ -101,7 +96,7 @@ class MSAServiceStatus(SQLModel):
     """
     **MSAServiceStatus** Pydantic Response Class
     """
-    name: Optional[str] = "MSA SDK Service"
+    name: Optional[str] = "msaSDK Service"
     """Service Name."""
     healthy: Optional[str] = "None"
     """Health status"""
@@ -113,7 +108,7 @@ class MSAOpenAPIInfo(SQLModel):
     """
     **MSAOpenAPIInfo** Pydantic Response Class
     """
-    name: str = "MSA SDK Service"
+    name: str = "msaSDK Service"
     """Service Name."""
     version: str = "0.0.0"
     """API Version."""
@@ -163,7 +158,7 @@ def getSecretKeyCSRF() -> str:
 
 
 class MSAApp(MSAFastAPI):
-    """Creates an application MSA SDK instance.
+    """Creates an application msaSDK instance.
 
     Note:
         As with FastApi the MSAApp provides two events:
@@ -445,7 +440,7 @@ class MSAApp(MSAFastAPI):
         :return:
         :rtype:
         """
-        self.logger.info("MSA SDK Internal Startup MSAUIEvent")
+        self.logger.info("msaSDK Internal Startup MSAUIEvent")
 
         if self.settings.db:
             async with self.db_engine.begin() as conn:
@@ -490,7 +485,7 @@ class MSAApp(MSAFastAPI):
             self.logger.error("Can't Mount Admin Site - Not initialized or enabled")
 
     async def shutdown_event(self) -> None:
-        self.logger.info("MSA SDK Internal Shutdown MSAUIEvent")
+        self.logger.info("msaSDK Internal Shutdown MSAUIEvent")
         if self.settings.scheduler and self.timers:
             self.logger.info("Stop Scheduler Timers: " + str(len(self.timers.timer_jobs)))
             await self.scheduler.stop_timers()
